summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorsatorux@chromium.org <satorux@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-11-01 10:40:45 +0000
committersatorux@chromium.org <satorux@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-11-01 10:40:45 +0000
commit6076cb943dbf1ac2ce53966aa2f9bbc952a4dfc4 (patch)
treeb832360527cad6ca74fc1df836977d3c94dbeb89
parent987713eb0368b4b9a13bd8d069dfcf5f2c4903f7 (diff)
downloadchromium_src-6076cb943dbf1ac2ce53966aa2f9bbc952a4dfc4.zip
chromium_src-6076cb943dbf1ac2ce53966aa2f9bbc952a4dfc4.tar.gz
chromium_src-6076cb943dbf1ac2ce53966aa2f9bbc952a4dfc4.tar.bz2
Replace "Restart" with "Sign out" in the Languages and Input page.
Here, the user just has to "sign out". The label "restart" is not relevant here. TEST=manually BUG=chromium-os:8177 Review URL: http://codereview.chromium.org/4096012 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@64590 0039d316-1c4b-4281-b951-d872f2087c98
-rw-r--r--chrome/app/generated_resources.grd6
-rw-r--r--chrome/browser/chromeos/dom_ui/language_options_handler.cc16
-rw-r--r--chrome/browser/chromeos/dom_ui/language_options_handler.h4
-rw-r--r--chrome/browser/resources/options/chromeos_language_options.html6
-rw-r--r--chrome/browser/resources/options/chromeos_language_options.js4
5 files changed, 17 insertions, 19 deletions
diff --git a/chrome/app/generated_resources.grd b/chrome/app/generated_resources.grd
index bee34da..263a019 100644
--- a/chrome/app/generated_resources.grd
+++ b/chrome/app/generated_resources.grd
@@ -9804,9 +9804,9 @@ Keep your key file in a safe place. You will need it to create new versions of y
desc="The label for the remove button for removing a language">
Remove
</message>
- <message name="IDS_OPTIONS_SETTINGS_LANGUAGES_RESTART_BUTTON"
- desc="The label for the restart button for changing UI language">
- Restart
+ <message name="IDS_OPTIONS_SETTINGS_LANGUAGES_SIGN_OUT_BUTTON"
+ desc="The label for the sign out button for changing UI language">
+ Sign out
</message>
<message name="IDS_OPTIONS_SETTINGS_LANGUAGES_PLEASE_ADD_ANOTHER_INPUT_METHOD"
desc="Warning invoked when the user tries to remove the last input method">
diff --git a/chrome/browser/chromeos/dom_ui/language_options_handler.cc b/chrome/browser/chromeos/dom_ui/language_options_handler.cc
index 0ef858227..a3f7056 100644
--- a/chrome/browser/chromeos/dom_ui/language_options_handler.cc
+++ b/chrome/browser/chromeos/dom_ui/language_options_handler.cc
@@ -56,8 +56,8 @@ void LanguageOptionsHandler::GetLocalizedValues(
localized_strings->SetString("ok_button", l10n_util::GetStringUTF16(IDS_OK));
localized_strings->SetString("remove_button",
l10n_util::GetStringUTF16(IDS_OPTIONS_SETTINGS_LANGUAGES_REMOVE_BUTTON));
- localized_strings->SetString("restart_button",
- l10n_util::GetStringUTF16(IDS_OPTIONS_SETTINGS_LANGUAGES_RESTART_BUTTON));
+ localized_strings->SetString("sign_out_button",
+ l10n_util::GetStringUTF16(IDS_OPTIONS_SETTINGS_LANGUAGES_SIGN_OUT_BUTTON));
localized_strings->SetString("add_language_instructions",
l10n_util::GetStringUTF16(
IDS_OPTIONS_SETTINGS_LANGUAGES_ADD_LANGUAGE_INSTRUCTIONS));
@@ -84,7 +84,7 @@ void LanguageOptionsHandler::GetLocalizedValues(
l10n_util::GetStringFUTF16(
IDS_OPTIONS_SETTINGS_LANGUAGES_DISPLAY_IN_THIS_LANGUAGE,
l10n_util::GetStringUTF16(IDS_PRODUCT_OS_NAME)));
- localized_strings->SetString("restart_required",
+ localized_strings->SetString("sign_out_required",
l10n_util::GetStringUTF16(IDS_OPTIONS_RESTART_REQUIRED));
localized_strings->SetString("this_language_is_currently_in_use",
l10n_util::GetStringFUTF16(
@@ -130,8 +130,8 @@ void LanguageOptionsHandler::RegisterMessages() {
&LanguageOptionsHandler::SpellCheckLanguageChangeCallback));
dom_ui_->RegisterMessageCallback("uiLanguageChange",
NewCallback(this, &LanguageOptionsHandler::UiLanguageChangeCallback));
- dom_ui_->RegisterMessageCallback("uiLanguageRestart",
- NewCallback(this, &LanguageOptionsHandler::RestartCallback));
+ dom_ui_->RegisterMessageCallback("uiLanguageSignOut",
+ NewCallback(this, &LanguageOptionsHandler::SignOutCallback));
}
ListValue* LanguageOptionsHandler::GetInputMethodList(
@@ -303,13 +303,11 @@ void LanguageOptionsHandler::SpellCheckLanguageChangeCallback(
UserMetrics::RecordComputedAction(action);
}
-void LanguageOptionsHandler::RestartCallback(const ListValue* args) {
- UserMetrics::RecordAction(UserMetricsAction("LanguageOptions_Restart"));
+void LanguageOptionsHandler::SignOutCallback(const ListValue* args) {
+ UserMetrics::RecordAction(UserMetricsAction("LanguageOptions_SignOut"));
Browser* browser = Browser::GetBrowserForController(
&dom_ui_->tab_contents()->controller(), NULL);
- // TODO(kochi): For ChromiumOS, just exiting means browser restart.
- // Implement browser restart for Chromium Win/Linux/Mac.
if (browser)
browser->ExecuteCommand(IDC_EXIT);
}
diff --git a/chrome/browser/resources/options/chromeos_language_options.html b/chrome/browser/resources/options/chromeos_language_options.html
index 1e5dd6f..89531ad 100644
--- a/chrome/browser/resources/options/chromeos_language_options.html
+++ b/chrome/browser/resources/options/chromeos_language_options.html
@@ -31,9 +31,9 @@
</div>
<div id="language-options-ui-notification-bar"
class="language-options-notification">
- <div i18n-content="restart_required"></div>
- <button id="language-options-ui-restart-button"
- i18n-content="restart_button"></button>
+ <div i18n-content="sign_out_required"></div>
+ <button id="language-options-ui-sign-out-button"
+ i18n-content="sign_out_button"></button>
</div>
<h3 i18n-content="input_method"></h3>
<div id="language-options-input-method-list"
diff --git a/chrome/browser/resources/options/chromeos_language_options.js b/chrome/browser/resources/options/chromeos_language_options.js
index 3474b4f..6b322ab 100644
--- a/chrome/browser/resources/options/chromeos_language_options.js
+++ b/chrome/browser/resources/options/chromeos_language_options.js
@@ -313,8 +313,8 @@ cr.define('options', function() {
uiLanguageButton.onclick = function(e) {
chrome.send('uiLanguageChange', [languageCode]);
}
- $('language-options-ui-restart-button').onclick = function(e) {
- chrome.send('uiLanguageRestart');
+ $('language-options-ui-sign-out-button').onclick = function(e) {
+ chrome.send('uiLanguageSignOut');
}
} else {
// If the language is not supported as UI language, the button
diff --git a/chrome/browser/chromeos/dom_ui/language_options_handler.h b/chrome/browser/chromeos/dom_ui/language_options_handler.h
index bd1c78a..ecb8d34 100644
--- a/chrome/browser/chromeos/dom_ui/language_options_handler.h
+++ b/chrome/browser/chromeos/dom_ui/language_options_handler.h
@@ -84,8 +84,8 @@ class LanguageOptionsHandler : public OptionsPageUIHandler {
// |args| will contain the language code as string (ex. "fr").
void SpellCheckLanguageChangeCallback(const ListValue* args);
- // Called when the restart button is clicked.
- void RestartCallback(const ListValue* args);
+ // Called when the sign out button is clicked.
+ void SignOutCallback(const ListValue* args);
DISALLOW_COPY_AND_ASSIGN(LanguageOptionsHandler);
};